==> 0.0.9.tar.gz: lib/pages/online_file_page.dart <==
import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:vone_ipfs/bean/folder_data_entity.dart';
import 'package:vone_ipfs/generated/json/base/json_convert_content.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/utils/toast_utils.dart';
import 'package:vone_ipfs/component/empty_view.dart';

import 'file_preview_page.dart';

class OnlineFilePage extends StatefulWidget {
  ValueChanged<List> resultCallback;
  int maxCount;
  String dirId;
  String dirName;
  IPFSFileType fileType;
  List<String>? allowedExtensions;
  OnlineFilePage(
    this.dirId,
    this.dirName,
    this.resultCallback, {
    Key? key,
    this.maxCount = 9,
        this.fileType=IPFSFileType.any,this.allowedExtensions
  }) : super(key: key);

  @override
  OnlineFilePageState createState() => new OnlineFilePageState();
}

class OnlineFilePageState extends State<OnlineFilePage> {
  late EasyRefreshController _controller;
  String currentParentID = '';
  List parentIDs = [];
  List _list = [];
  List selectedFile = [];

  //当前页
  int current = 1;

  //每页加载数量
  int size = 15;

  //是否还有更多
  bool isMore = false;

  @override
  void initState() {
    super.initState();
    _controller = EasyRefreshController();
    currentParentID = widget.dirId;
    parentIDs.add(widget.dirId);
    loadFile(currentParentID);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('云端文件'),
        actions: [
          InkWell(
            child: const Center(
              child: Padding(
                child: Text('确定'),
                padding: EdgeInsets.symmetric(horizontal: 15),
              ),
            ),
            onTap: () {
              widget.resultCallback(selectedFile);
              Navigator.pop(context);
            },
          )
        ],
        centerTitle: true,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildTips(),
          _buildFileList(),
        ],
      ),
    );
  }

  _buildTips() {
    return Padding(
      padding: const EdgeInsets.all(10),
      child: Wrap(
        spacing: 10,
        children: [
          Visibility(
            child: InkWell(
              child: const Text(
                '返回到上一级',
                style: TextStyle(fontSize: 14, color: Colors.blue),
              ),
              onTap: () {
                parentIDs.removeLast();
                currentParentID = parentIDs.last;
                current = 1;
                loadFile(currentParentID);
              },
            ),
            visible: parentIDs.length > 1,
          ),
          Text(
            '${_fileSelectTips()}',
            style: TextStyle(fontSize: 14, color: Colors.black87),
          )
        ],
      ),
    );
  }

  _fileSelectTips(){
    String tips='';
    switch(widget.fileType){
      case IPFSFileType.any:
        tips = '';
        break;
      case IPFSFileType.video:
        tips = '只能选择视频文件';
        break;
      case IPFSFileType.image:
        tips = '只能选择图片文件';
        break;
      case IPFSFileType.audio:
        tips = '只能选择音频文件';
        break;
      case IPFSFileType.media:
      case IPFSFileType.imageAndVideo:
      tips = '只能选择媒体文件';
        break;
      case IPFSFileType.custom:
        tips = '只能选择${(widget.allowedExtensions??[]).join('/')}格式文件';
        break;
    }
    return tips;
  }


  _buildFileList() {
    return Expanded(
      child: EasyRefresh(
          controller: _controller,
          header: ClassicalHeader(
              enableInfiniteRefresh: false,
              refreshText: '下拉刷新',
              refreshReadyText: '释放刷新',
              refreshingText: '正在刷新...',
              refreshedText: '刷新完成',
              refreshFailedText: '刷新失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          footer: ClassicalFooter(
              enableInfiniteLoad: true,
              loadText: '拉动加载',
              loadReadyText: '释放加载',
              loadingText: '正在加载...',
              loadedText: '加载完成',
              loadFailedText: '加载失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          onRefresh: () async {
            current = 1;
            loadFile(currentParentID);
            _controller.finishRefresh();
            if (isMore) {
              _controller.resetLoadState();
            }
          },
          onLoad: isMore
              ? () async {
                  _controller.finishLoad(noMore: !isMore);
                  loadFile(currentParentID);
                }
              : null,
          emptyWidget: _list.length > 0 ? null : EmptyView(),
          child: ListView.builder(
            itemBuilder: (context, index) {
              return _buildFileItem(index);
            },
            itemCount: _list.length,
          )),
    );
  }

  Widget _buildFileItem(int index) {
    String time = _list[index].updated.toString()+"000";
    String dateTime = DateTime.fromMillisecondsSinceEpoch(int.parse(time))
        .toLocal().toString().substring(0,19);
    return InkWell(
      child: Container(
        padding: const EdgeInsets.all(10),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            IPFSUtils.getFileIconBySuffix("${_list[index].fileName}",
                fileType: "${_list[index].fileType}"),
            const SizedBox(
              width: 15,
            ),
            Expanded(
                child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  '${_list[index].fileName}',
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                  style: const TextStyle(fontSize: 16, color: Colors.black87),
                ),
                Text(
                  dateTime,
                  style: const TextStyle(fontSize: 14, color: Colors.grey),
                ),
                //   TextSpan(
                //     text: '    10M',
                //     style: TextStyle(fontSize: 12, color: Colors.grey),
                //   )
                // ])),
              ],
            )),
            // Icon(Icons.panorama_fish_eye,size: 20,color: Color(0xFF999999),)
            Visibility(
                visible: !IPFSUtils.isDir('${_list[index].fileType}') && IPFSUtils.isAllowFileType(_list[index].fileName, widget.fileType,allowedExtensions: widget.allowedExtensions),
                child: InkWell(
                  child: Padding(
                    child: Icon(
                      isSelected(_list[index].id)
                          ? Icons.check_circle
                          : Icons.radio_button_unchecked,
                      size: 20,
                      color: isSelected(_list[index].id)
                          ? Colors.blue
                          : Color(0xFF999999),
                    ),
                    padding: EdgeInsets.symmetric(horizontal: 10),
                  ),
                  onTap: () {
                    setState(() {
                      if (isSelected(_list[index].id)) {
                        selectedFile.removeWhere(
                            (element) => element.id == _list[index].id);
                      } else {
                        if (selectedFile.length >= widget.maxCount) {
                          ToastUtils.show('最多可选择${widget.maxCount}个文件');
                          return;
                        }
                        selectedFile.add(_list[index]);
                      }
                    });
                  },
                ))
          ],
        ),
      ),
      onTap: () {
        if (IPFSUtils.isDir('${_list[index].fileType}')) {
          //如果是文件夹,进入下一级
          currentParentID = '${_list[index].id}';
          current = 1;
          parentIDs.add(currentParentID);
          loadFile('${_list[index].id}');
        } else {
          Navigator.push(context, MaterialPageRoute(builder: (context) {
            return FilePreviewPage(
                fileUrl: IPFSUtils.instance!
                    .getFilePath(_list[index].id, _list[index].fileName));
          }));
        }
      },
    );
  }

  isSelected(fileId) {
    return selectedFile.where((element) => element.id == fileId).length > 0;
  }

  loadFile(String parentID) async {
    Response response;
    Dio dio = Dio();
    Map<String, dynamic> param = {
      "userID": IPFSUtils.instance!.userId,
      "secretKey": IPFSUtils.instance!.secretKey,
      "fileID": parentID,
      'page': current,
      'pageSize': size,
      'onlyDir': false
    };
    response =
        await dio.get<String>("${IPFSUtils.instance!.requestUrl}${HttpApi.getFolderList}", queryParameters: param);
    print(response.data.toString());
    if (200 == response.statusCode) {
      FolderDataEntity fileData = JsonConvert.fromJsonAsT<FolderDataEntity>(
          jsonDecode(response.data.toString()));
      if (fileData.code == 0) {
        setListData(fileData.data?.xList);
      }
    }
  }

  setListData(data) {
    if (current == 1) {
      _list = [];
    }
    if (data != null && data.length > 0) {
      if (data.length < size) {
        isMore = false;
      } else {
        isMore = true;
      }
      _list.addAll(data);
      current += 1;
    } else {
      isMore = false;
    }
    setState(() {});
  }

  @override
  void dispose() {
    super.dispose();
  }
}

==> 0.0.22.tar.gz: lib/pages/online_file_page.dart <==
import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:vone_ipfs/bean/folder_data_entity.dart';
import 'package:vone_ipfs/generated/json/base/json_convert_content.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/utils/toast_utils.dart';
import 'package:vone_ipfs/component/empty_view.dart';

import 'file_preview_page.dart';

class OnlineFilePage extends StatefulWidget {
  ValueChanged<List> resultCallback;
  int maxCount;
  String dirId;
  String dirName;
  IPFSFileType fileType;
  List<String>? allowedExtensions;
  OnlineFilePage(
    this.dirId,
    this.dirName,
    this.resultCallback, {
    Key? key,
    this.maxCount = 9,
        this.fileType=IPFSFileType.any,this.allowedExtensions
  }) : super(key: key);

  @override
  OnlineFilePageState createState() => new OnlineFilePageState();
}

class OnlineFilePageState extends State<OnlineFilePage> {
  late EasyRefreshController _controller;
  String currentParentID = '';
  List parentIDs = [];
  List _list = [];
  List selectedFile = [];

  //当前页
  int current = 1;

  //每页加载数量
  int size = 15;

  //是否还有更多
  bool isMore = false;

  @override
  void initState() {
    super.initState();
    _controller = EasyRefreshController();
    currentParentID = widget.dirId;
    parentIDs.add(widget.dirId);
    loadFile(currentParentID);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('云端文件'),
        actions: [
          InkWell(
            child: const Center(
              child: Padding(
                child: Text('确定'),
                padding: EdgeInsets.symmetric(horizontal: 15),
              ),
            ),
            onTap: () {
              widget.resultCallback(selectedFile);
              Navigator.pop(context);
            },
          )
        ],
        centerTitle: true,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildTips(),
          _buildFileList(),
        ],
      ),
    );
  }

  _buildTips() {
    return Padding(
      padding: const EdgeInsets.all(10),
      child: Wrap(
        spacing: 10,
        children: [
          Visibility(
            child: InkWell(
              child: const Text(
                '返回到上一级',
                style: TextStyle(fontSize: 14, color: Colors.blue),
              ),
              onTap: () {
                parentIDs.removeLast();
                currentParentID = parentIDs.last;
                current = 1;
                loadFile(currentParentID);
              },
            ),
            visible: parentIDs.length > 1,
          ),
          Text(
            '${_fileSelectTips()}',
            style: TextStyle(fontSize: 14, color: Colors.black87),
          )
        ],
      ),
    );
  }

  _fileSelectTips(){
    String tips='';
    switch(widget.fileType){
      case IPFSFileType.any:
        tips = '';
        break;
      case IPFSFileType.video:
        tips = '只能选择视频文件';
        break;
      case IPFSFileType.image:
        tips = '只能选择图片文件';
        break;
      case IPFSFileType.audio:
        tips = '只能选择音频文件';
        break;
      case IPFSFileType.media:
      case IPFSFileType.imageAndVideo:
      tips = '只能选择媒体文件';
        break;
      case IPFSFileType.custom:
        tips = '只能选择${(widget.allowedExtensions??[]).join('/')}格式文件';
        break;
    }
    return tips;
  }


  _buildFileList() {
    return Expanded(
      child: EasyRefresh(
          controller: _controller,
          header: ClassicalHeader(
              enableInfiniteRefresh: false,
              refreshText: '下拉刷新',
              refreshReadyText: '释放刷新',
              refreshingText: '正在刷新...',
              refreshedText: '刷新完成',
              refreshFailedText: '刷新失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          footer: ClassicalFooter(
              enableInfiniteLoad: true,
              loadText: '拉动加载',
              loadReadyText: '释放加载',
              loadingText: '正在加载...',
              loadedText: '加载完成',
              loadFailedText: '加载失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          onRefresh: () async {
            current = 1;
            loadFile(currentParentID);
            _controller.finishRefresh();
            if (isMore) {
              _controller.resetLoadState();
            }
          },
          onLoad: isMore
              ? () async {
                  _controller.finishLoad(noMore: !isMore);
                  loadFile(currentParentID);
                }
              : null,
          emptyWidget: _list.length > 0 ? null : EmptyView(),
          child: ListView.builder(
            itemBuilder: (context, index) {
              return _buildFileItem(index);
            },
            itemCount: _list.length,
          )),
    );
  }

  Widget _buildFileItem(int index) {
    String time = _list[index].updated.toString()+"000";
    String dateTime = DateTime.fromMillisecondsSinceEpoch(int.parse(time))
        .toLocal().toString().substring(0,19);
    return InkWell(
      child: Container(
        padding: const EdgeInsets.all(10),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            IPFSUtils.getFileIconBySuffix("${_list[index].fileName}",
                fileType: "${_list[index].fileType}"),
            const SizedBox(
              width: 15,
            ),
            Expanded(
                child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  '${_list[index].fileName}',
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                  style: const TextStyle(fontSize: 16, color: Colors.black87),
                ),
                Text(
                  dateTime,
                  style: const TextStyle(fontSize: 14, color: Colors.grey),
                ),
                //   TextSpan(
                //     text: '    10M',
                //     style: TextStyle(fontSize: 12, color: Colors.grey),
                //   )
                // ])),
              ],
            )),
            // Icon(Icons.panorama_fish_eye,size: 20,color: Color(0xFF999999),)
            Visibility(
                visible: !IPFSUtils.isDir('${_list[index].fileType}') && IPFSUtils.isAllowFileType(_list[index].fileName, widget.fileType,allowedExtensions: widget.allowedExtensions),
                child: InkWell(
                  child: Padding(
                    child: Icon(
                      isSelected(_list[index].id)
                          ? Icons.check_circle
                          : Icons.radio_button_unchecked,
                      size: 20,
                      color: isSelected(_list[index].id)
                          ? Colors.blue
                          : Color(0xFF999999),
                    ),
                    padding: EdgeInsets.symmetric(horizontal: 10),
                  ),
                  onTap: () {
                    setState(() {
                      if (isSelected(_list[index].id)) {
                        selectedFile.removeWhere(
                            (element) => element.id == _list[index].id);
                      } else {
                        if (selectedFile.length >= widget.maxCount) {
                          ToastUtils.show('最多可选择${widget.maxCount}个文件');
                          return;
                        }
                        selectedFile.add(_list[index]);
                      }
                    });
                  },
                ))
          ],
        ),
      ),
      onTap: () {
        if (IPFSUtils.isDir('${_list[index].fileType}')) {
          //如果是文件夹,进入下一级
          currentParentID = '${_list[index].id}';
          current = 1;
          parentIDs.add(currentParentID);
          loadFile('${_list[index].id}');
        } else {
          Navigator.push(context, MaterialPageRoute(builder: (context) {
            return FilePreviewPage(
                fileUrl: '${IPFSUtils.instance!
                    .getFilePath(_list[index].id, _list[index].fileName)}');
          }));
        }
      },
    );
  }

  isSelected(fileId) {
    return selectedFile.where((element) => element.id == fileId).length > 0;
  }

  loadFile(String parentID) async {
    Response response;
    Dio dio = Dio();
    Map<String, dynamic> param = {
      "userID": IPFSUtils.instance!.userId,
      "secretKey": IPFSUtils.instance!.secretKey,
      "fileID": parentID,
      'page': current,
      'pageSize': size,
      'onlyDir': false
    };
    response =
        await dio.get<String>("${IPFSUtils.instance!.requestUrl}${HttpApi.getFolderList}", queryParameters: param);
    print(response.data.toString());
    if (200 == response.statusCode) {
      FolderDataEntity fileData = JsonConvert.fromJsonAsT<FolderDataEntity>(
          jsonDecode(response.data.toString()));
      if (fileData.code == 0) {
        setListData(fileData.data?.xList);
      }
    }
  }

  setListData(data) {
    if (current == 1) {
      _list = [];
    }
    if (data != null && data.length > 0) {
      if (data.length < size) {
        isMore = false;
      } else {
        isMore = true;
      }
      _list.addAll(data);
      current += 1;
    } else {
      isMore = false;
    }
    setState(() {});
  }

  @override
  void dispose() {
    super.dispose();
  }
}
